@@ -1,4 +1,13 @@
 #!/bin/sh
+### BEGIN INIT INFO
+# Provides:          keymap
+# Required-Start:    mountvirtfs
+# Required-Stop:     
+# Default-Start:     S 1 2 3 4 5
+# Default-Stop:      0 6
+### END INIT INFO
+
+. /lib/lsb/init-functions
 
 #
 # Load the keymaps *as soon as possible*
@@ -9,8 +18,9 @@ CONSOLE_TYPE=`fgconsole 2>/dev/null` || CONSOLE_TYPE="unknown"
 
 # Don't fail on serial consoles
 
+QUIT=0
 # fail silently if loadkeys not present (yet).
-command -v loadkeys >/dev/null 2>&1 || exit 0
+command -v loadkeys >/dev/null 2>&1 || QUIT=1
 
 CONFDIR=/etc/console
 CONFFILEROOT=boottime
@@ -37,8 +47,8 @@ unicode_start_stop()
 {
 	# Switch unicode mode by checking the locale.
 	# This will be needed before loading the keymap.
-	[ -x /usr/bin/unicode_start ] || return
-	[ -x /usr/bin/unicode_stop ] || return
+	[ -x /usr/bin/unicode_start ] || [ -x /bin/unicode_start ] ||  return
+	[ -x /usr/bin/unicode_stop ] || [ -x /bin/unicode_stop ] || return
 	[ -r /etc/environment ] || return
 	
 	for var in LANG LC_ALL LC_CTYPE; do
@@ -48,24 +58,26 @@ unicode_start_stop()
 
 	CHARMAP=`LANG=$LANG LC_ALL=$LC_ALL LC_CTYPE=$LC_CTYPE locale charmap`
 	if [ "$CHARMAP" = "UTF-8" ]; then
-		/usr/bin/unicode_start 2> /dev/null || true
+		unicode_start 2> /dev/null || true
 	else
-		/usr/bin/unicode_stop 2> /dev/null || true
+		unicode_stop 2> /dev/null || true
 	fi
 }
 
-case "$1" in
-    start | restart | force-reload | reload)
+if [ ! $QUIT = '1' ] ; then
 
-       # First mount /proc if necessary.
-       unmount_proc="no"
-       if [ ! -x /proc/1 ]; then
-      	unmount_proc="yes"	
-        mount -n /proc
-       fi
-
-	# Set kernel variables if required
-	reset_kernel
+  case "$1" in
+      start | restart | force-reload | reload)
+  
+         # First mount /proc if necessary.
+         unmount_proc="no"
+         if [ ! -x /proc/1 ]; then
+        	unmount_proc="yes"	
+          mount -n /proc
+         fi
+  
+      	# Set kernel variables if required
+    	reset_kernel
 
         if [ -f /proc/sys/dev/mac_hid/keyboard_sends_linux_keycodes ] ; then
            linux_keycodes=`cat /proc/sys/dev/mac_hid/keyboard_sends_linux_keycodes`
@@ -89,11 +101,10 @@ case "$1" in
 		then
 	    	# if we've a serial console, we may not have a keyboard, so don't
 		# complain if we fail. 
-		[ $CONSOLE_TYPE = "serial" ] && exit 0
-
-		echo "Problem when loading ${CONFDIR}/${CONFFILEROOT}.${EXT}.gz"
-		echo "use install-keymap"
-		sleep 10
+		   if [ ! $CONSOLE_TYPE = "serial" ]; then 
+			log_warning_msg "Problem when loading ${CONFDIR}/${CONFFILEROOT}.${EXT}.gz, use install-keymap"
+			sleep 10
+		   fi 
 		fi
 	    fi
 	fi
@@ -104,12 +115,11 @@ case "$1" in
 	;;
 
     stop)
-# 	# ensure the saved kernel keymap is removed before halt/reboot
-# 	rm -f ${KERNEL_KEYMAP}
 	;;
 
     *)
-	echo "Usage: $0 {start|stop|restart|reload|force-reload}"
-	exit 1
+	log_warning_msg "Usage: $0 {start|stop|restart|reload|force-reload}"
 	;;
-esac
+  esac
+
+fi
